@@ -108,16 +108,18 @@ class FileHandlerJSON(FileHandler):
 
     @staticmethod
     def _load_any_from_json_file(filename, data_only: bool = True) -> dict or list:
-        if not RTB.check_file(filename):
-            return None
-        with open(filename, 'r') as file:
-            data = json.load(file)
-            if data.get('data', None):
-                data['date'] = RTB.convert_str_to_datetime(data['date'])
-            log.debug(f'Loaded file{filename}, dated: {data.get("date", None)}')
+        try:
+            with open(filename, 'r') as file:
+                data = json.load(file)
+                if data.get('data', None):
+                    data['date'] = RTB.convert_str_to_datetime(data['date'])
+                log.debug(f'Loaded file{filename}, dated: {data.get("date", None)}')
             if data_only:
                 return data.get('data', None)
-        return data
+            return data
+        except FileNotFoundError as e:
+            log.error(f"File '{filename}' Not Found : {e}")
+            return None
 
     def load_dict_from_file(self, filename: str = None, data_only: bool = True) -> dict:
         """load dict object from .json file"""
@@ -150,12 +152,17 @@ class FileHandlerYAML(FileHandler):
         return True
 
     @staticmethod
-    def _load_any_from_yml_file(filename: str = None, data_only: bool = True) -> dict:
-        with open(filename, 'r') as f:
-            data = yaml.safe_load(f)
-        if data_only:
-            return data.get('data', None)
-        return data
+    def _load_any_from_yml_file(filename: str = None, data_only: bool = True) -> dict or list:
+        try:
+            with open(filename, 'r') as f:
+                data = yaml.safe_load(f)
+                log.debug(f'Loaded file{filename}, dated: {data.get("date", None)}')
+            if data_only:
+                return data.get('data', None)
+            return data
+        except FileNotFoundError as e:
+            log.error(f"File '{filename}' Not Found : {e}")
+            return None
 
     def load_dict_from_file(self, filename: str = None, data_only: bool = True) -> dict:
         filename = self.check_filename(filename)
@@ -164,7 +171,7 @@ class FileHandlerYAML(FileHandler):
             return data
         return {}
 
-    def load_list_from_file(self, filename: str = None, data_only: bool = True) -> dict:
+    def load_list_from_file(self, filename: str = None, data_only: bool = True) -> list:
         filename = self.check_filename(filename)
         data = self._load_any_from_yml_file(filename=filename, data_only=data_only)
         if type(data) is list:
